.. _spkg_xz:

xz: General-purpose data compression software
=======================================================

Description
-----------

XZ Utils is free general-purpose data compression software with a high
compression ratio.

License
-------

Some parts public domain, other parts GNU LGPLv2.1, GNU GPLv2, or GNU
GPLv3.


Upstream Contact
----------------

http://tukaani.org/xz/

Dependencies
------------

Type
----

standard


Dependencies
------------


Version Information
-------------------

package-version.txt::

    5.2.5


Equivalent System Packages
--------------------------

.. tab:: Alpine

   .. CODE-BLOCK:: bash

       $ apk add xz 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install xz 


.. tab:: Debian/Ubuntu

   .. CODE-BLOCK:: bash

       $ sudo apt-get install xz-utils 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo yum install xz 


.. tab:: Homebrew

   .. CODE-BLOCK:: bash

       $ brew install xz 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install xz 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install xz 


.. tab:: Slackware

   .. CODE-BLOCK:: bash

       $ sudo slackpkg install xz 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install xz 



See https://repology.org/project/xz/versions

If the system package is installed, ``./configure`` will check if it can be used.

